@@ -1,7 +1,7 @@
 from steroids.modules import apscheduler
 from steroids.modules import honcho
 from steroids.modules import mongodb
-from steroids.modules import tornado
+from steroids.modules import flasktornado
 from steroids.modules import bootstrap
 from steroids.modules import topcoat
 from steroids.modules import flask
